@@ -36,13 +36,9 @@
 #include <sys/ioctl.h>
 #include <sys/socket.h>
 
-#include <bluetooth/bluetooth.h>
-#include <bluetooth/hci.h>
-#include <bluetooth/hci_lib.h>
-
-#include <netinet/in.h>
-
 #include "parser/parser.h"
+#include "lib/hci.h"
+#include "lib/hci_lib.h"
 
 static volatile sig_atomic_t __io_canceled = 0;
 
